==> dnet-openaire-exporter-1.0.9-20180309.112154-95-sources.jar: eu/dnetlib/openaire/common/ExporterConstants.java <==
package eu.dnetlib.openaire.common;

public class ExporterConstants {

	/*
	Tags used to group the operations on the swagger UI
    */
	public final static String C = "Community";
	public final static String C_CP = "Community content providers";
	public final static String C_PJ = "Community projects";

	public final static String DS = "Datasource";
	public final static String API = "Interface";
	public final static String R = "Read";
	public final static String W = "Write";

	public final static String D = "Deprecated";
	public final static String M = "Management";

	public final static String DSPACE = "DSpace";
	public final static String EPRINT = "EPrints";
	public final static String TSV = "TSV";
	public final static String STREAMING = "Streaming";

	// Paths used in the repository profile mapping: Datasource
	public static final String ADMIN_INFO       = "//CONFIGURATION/ADMIN_INFO";
	public static final String ENGLISH_NAME     = "//CONFIGURATION/ENGLISH_NAME";
	public static final String OFFICIAL_NAME    = "//CONFIGURATION/OFFICIAL_NAME";
	public static final String TIMEZONE         = "//CONFIGURATION/LOCATION/TIMEZONE";
	public static final String LATITUDE         = "//CONFIGURATION/LOCATION/LATITUDE";
	public static final String LONGITUDE        = "//CONFIGURATION/LOCATION/LONGITUDE";
	public static final String PLATFORM         = "//CONFIGURATION/TYPOLOGY";
	public static final String TYPOLOGY         = "//CONFIGURATION/DATASOURCE_TYPE";
	public static final String WEBSITE_URL      = "//CONFIGURATION/REPOSITORY_WEBPAGE";

	// Paths used in the repository profile mapping: Interface
	public static final String BASE_URL         = "/BASE_URL";
	public static final String COMPLIANCE       = "/@compliance";

}

==> dnet-openaire-exporter-1.1.0-20190619.081008-376-sources.jar: eu/dnetlib/openaire/common/ExporterConstants.java <==
package eu.dnetlib.openaire.common;

public class ExporterConstants {

	/*
	Tags used to group the operations on the swagger UI
    */
	public final static String C = "Community";
	public final static String C_CP = "Community content providers";
	public final static String C_PJ = "Community projects";
	public final static String C_ZC = "Community Zenodo Communities";

	public final static String DS = "Datasource";
	public final static String API = "Interface";
	public final static String R = "Read";
	public final static String W = "Write";

	public final static String D = "Deprecated";
	public final static String M = "Management";

	public final static String DSPACE = "DSpace";
	public final static String EPRINT = "EPrints";
	public final static String TSV = "TSV";
	public final static String STREAMING = "Streaming";

	public static final String OAI = "oai";
	public static final String SET = "set";

	// Paths used in the repository profile mapping: Datasource
	public static final String ADMIN_INFO       = "//CONFIGURATION/ADMIN_INFO";
	public static final String ENGLISH_NAME     = "//CONFIGURATION/ENGLISH_NAME";
	public static final String OFFICIAL_NAME    = "//CONFIGURATION/OFFICIAL_NAME";
	public static final String TIMEZONE         = "//CONFIGURATION/LOCATION/TIMEZONE";
	public static final String LATITUDE         = "//CONFIGURATION/LOCATION/LATITUDE";
	public static final String LONGITUDE        = "//CONFIGURATION/LOCATION/LONGITUDE";
	public static final String PLATFORM         = "//CONFIGURATION/TYPOLOGY";
	public static final String TYPOLOGY         = "//CONFIGURATION/DATASOURCE_TYPE";
	public static final String WEBSITE_URL      = "//CONFIGURATION/REPOSITORY_WEBPAGE";

	// Paths used in the repository profile mapping: Interface
	public static final String OAI_SET          = "/ACCESS_PROTOCOL/@set";
	public static final String BASE_URL         = "/BASE_URL";
	public static final String COMPLIANCE       = "/@compliance";

}
